module Elabs
  module Admin
    class LicensesController < AdminApplicationController
      DEFAULT_ORDER_FIELD = 'name'.freeze

      before_action :set_license, only: %i[edit update destroy]

      # GET /licenses
      # GET /licenses.json
      def index
        order     = params['order_by'] || self.class::DEFAULT_ORDER_FIELD
        direction = params['direction'] || 'desc'
        @licenses = License.order(order => direction).all
      end

      # GET /licenses/new
      def new
        @license = License.new
      end

      # GET /licenses/1/edit
      def edit; end

      # POST /licenses
      # POST /licenses.json
      def create
        @license = License.new(license_params)

        respond_to do |format|
          if @license.save
            format.html { redirect_to admin_licenses_url, notice: _('License was successfully created.') }
            format.json { render '_license', status: :created, location: @license, locals: { license: @license } }
          else
            format.html { render :new }
            format.json { render json: @license.errors, status: :unprocessable_entity }
          end
        end
      end

      # PATCH/PUT /licenses/1
      # PATCH/PUT /licenses/1.json
      def update
        respond_to do |format|
          if @license.update(license_params)
            format.html { redirect_to admin_licenses_url, notice: _('License was successfully updated.') }
            format.json { render '_license', status: :ok, location: @license, locals: { license: @license } }
          else
            format.html { render :edit }
            format.json { render json: @license.errors, status: :unprocessable_entity }
          end
        end
      end

      # DELETE /licenses/1
      # DELETE /licenses/1.json
      def destroy
        @license.destroy
        respond_to do |format|
          format.html { redirect_to admin_licenses_url, notice: _('License was successfully destroyed.') }
          format.json { head :no_content }
        end
      end

      private

      # Use callbacks to share common setup or constraints between actions.
      def set_license
        @license = License.find_by_slug(params[:slug])
      end

      # Never trust parameters from the scary internet, only allow the white list through.
      def license_params
        params.require(:license).permit(:name, :url, :tldr_url, :icon)
      end
    end
  end
end
