module Elabs
  module NotificationHelper
    def notification_message(notification)
      user   = notification_user notification.source_user
      action = notification_action notification.event
      link   = notification_link notification
      string = notification_string notification
      format(string, user: user, action: action, link: link).html_safe
    end

    def notification_icon(event)
      actions = {
        comment: 'comment',
        report:  'flag',
        lock:    'lock',
        unlock:  'unlock',
        delete:  'trash'
      }.freeze
      icon (actions[event.to_sym] || 'question'), ['fw']
    end

    def notification_count
      Elabs::Notification.for_user(current_user).count
    end

    private

    def notification_action(event)
      actions = {
        comment: _('has commented'),
        report:  _('has reported'),
        lock:    _('has locked'),
        unlock:  _('has unlocked'),
        delete:  _('has deleted')
      }.freeze
      actions[event.to_sym] || "[missing: #{event}]"
    end

    def notification_user(user)
      return link_to user.display_name, user if user

      _('Someone')
    end

    def notification_link(notification)
      return "##{notification.content_id}" if notification.event == 'delete'

      link = case notification.content_type
             when 'Elabs::Report'
               admin_reports_path
             when 'Elabs::Comment'
               url_for notification.content.content
             else
               notification.content
             end
      title = notification_link_title notification

      link_to(title, link).html_safe
    end

    def notification_link_title(notification)
      case notification.content_type
      when 'Elabs::Comment'
        notification.content.content.title_to_display
      else
        "##{notification.content_id}"
      end
    end

    def notification_string(notification)
      strings = {
        'Elabs::Album'   => _('%<user>s %<action>s your album %<link>s'),
        'Elabs::Article' => _('%<user>s %<action>s your article %<link>s'),
        'Elabs::Note'    => _('%<user>s %<action>s your note %<link>s'),
        'Elabs::Project' => _('%<user>s %<action>s your project %<link>s'),
        'Elabs::Upload'  => _('%<user>s %<action>s your file %<link>s'),
        'Elabs::Report'  => _('%<user>s %<action>s %<link>s'),
        'Elabs::Comment' => _('%<user>s %<action>s %<link>s')
      }.freeze
      strings[notification.content_type] || '%<user> %<action>s something (<%link>)'
    end
  end
end
