module Elabs
  module Concerns
    module ActableEntity
      extend ActiveSupport::Concern

      included do
        attr_accessor :update_description
        attr_reader :minor_update

        has_many :acts, as: :content

        before_save :update_acts?
        after_save :update_acts

        before_destroy :update_acts_on_delete
      end

      def minor_update=(value)
        @minor_update = ['t', '1', 1, true].include? value
      end

      def minor_update?
        @minor_update || false
      end

      private

      def update_acts?
        # byebug
        @action = if minor_update?
                    :nothing
                  elsif changed.include?('published')
                    current_publish_action
                  elsif changed.include?('locked') && published?
                    current_lock_action
                  elsif (changed & %w[title name description short_description content excerpt]).any?
                    current_update_action
                  else
                    :nothing
                  end
      end

      def update_acts
        acts.destroy_all if %i[lock unpublish].include? @action
        reason = update_description.nil? ? nil : update_description
        Act.create content: self, event: @action, reason: reason unless @action == :nothing || hidden_in_history
      end

      # TODO: check if used ? (dependent: destroy may do the trick.)
      def update_acts_on_delete
        acts.destroy_all
      end
    end
  end
end
