module Elabs
  class Language < ApplicationRecord
    self.table_name = 'languages'
    include Elabs::Concerns::Sluggable

    SLUGGABLE_FIELD = nil
    SLUG_FIELD = :iso639_1

    validates :iso639_1, presence: true
    validates :name,     presence: true

    has_many :albums
    has_many :articles
    has_many :notes
    has_many :projects
    has_many :uploads

    scope :with_content_only, -> { where.not(albums_count: 0).or(where.not(articles_count: 0)).or(where.not(notes_count: 0)).or(where.not(projects_count: 0)).or(where.not(uploads_count: 0)) }
    scope :available_site_translations, -> { select(:id, :name, :iso639_1).where(iso639_1: I18n.available_locales) }
    scope :for_list, -> { order(:name).pluck(:name, :id) }

    def to_param
      iso639_1
    end
  end
end
