module Elabs
  class Note < ApplicationContentRecord
    self.table_name = 'notes'

    SLUGGABLE_FIELD = :created_at
    ADDITIONAL_HABTM_COUNTER_CACHES = [
      %w[projects notes]
    ].freeze

    validates :content, presence: true
    validates :slug,    presence: true, uniqueness: true
    validates_with AssociatedAuthorValidator, relations: %w[project]

    belongs_to :user
    belongs_to :license
    belongs_to :language
    has_many :notes_tags
    has_many :projects_notes
    has_many :tags,     through: :notes_tags,     dependent: :destroy
    has_many :projects, through: :projects_notes, dependent: :destroy
    has_many :comments, as: 'content'
    has_many :visible_projects, -> { where(published: true, locked: false) },
             through: :projects_notes, source: :project

    def title_to_display
      I18n.l published_at, format: :medium
    end

    def short_text_to_display
      content
    end

    def long_text_to_display
      nil
    end
  end
end
