module Elabs
  class Project < ApplicationContentRecord
    self.table_name = 'projects'

    SLUGGABLE_FIELD = :name

    validates :name,              presence: true
    validates :short_description, presence: true
    validates :description,       presence: true
    validates :slug,              presence: true, uniqueness: true
    validates_with AssociatedAuthorValidator, relations: %w[album article note upload]

    belongs_to :user
    belongs_to :license
    belongs_to :language
    has_many :projects_tags
    has_many :projects_albums
    has_many :projects_articles
    has_many :projects_notes
    has_many :projects_uploads
    has_many :tags,     through: :projects_tags,     dependent: :destroy
    has_many :albums,   through: :projects_albums,   dependent: :destroy
    has_many :articles, through: :projects_articles, dependent: :destroy
    has_many :notes,    through: :projects_notes,    dependent: :destroy
    has_many :uploads,  through: :projects_uploads,  dependent: :destroy
    has_many :comments, as: 'content'

    scope :for_list, -> { order(:name).pluck(:name, :id) }

    def title_to_display
      name
    end

    def short_text_to_display
      short_description
    end

    def long_text_to_display
      description
    end
  end
end
