module Elabs
  class Upload < ApplicationContentRecord
    self.table_name = 'uploads'

    SLUGGABLE_FIELD = :title
    ADDITIONAL_HABTM_COUNTER_CACHES = [
      %w[albums uploads],
      %w[projects uploads]
    ].freeze

    validates :title,           presence: true
    validates :description,     presence: true
    validates :file_attachment, presence: true
    validates :slug,            presence: true, uniqueness: true
    validates_with AssociatedAuthorValidator, relations: %w[album project]

    belongs_to :user
    belongs_to :license
    belongs_to :language
    has_many :uploads_tags
    has_many :projects_uploads
    has_many :albums_uploads
    has_many :tags,     through: :uploads_tags,     dependent: :destroy
    has_many :projects, through: :projects_uploads, dependent: :destroy
    has_many :albums,   through: :albums_uploads,   dependent: :destroy
    has_many :comments, as: 'content'
    has_many :visible_projects, -> { where(published: true, locked: false) },
             through: :projects_uploads, source: :project
    has_many :visible_albums, -> { where(published: true, locked: false) },
             through: :albums_uploads, source: :album

    has_one_attached :file

    scope :for_list, -> { order(:title).pluck(:title, :id) }

    def title_to_display
      title
    end

    def short_text_to_display
      nil
    end

    def long_text_to_display
      description
    end
  end
end
